@@ -29,11 +29,11 @@
 #include <QAction>
 #include <QProgressBar>
 #include <QCheckBox>
-#include <KPushButton>
-#include <KMenuBar>
+#include <QPushButton>
 #include <KDebug>
 #include <KMessageBox>
 #include <KGlobalSettings>
+#include <KLocalizedString>
 
 #include "InfoWidget.h"
 #include "SimplePage.h"
@@ -80,7 +80,7 @@ SetupWizard::SetupWizard(QWidget *parent)
             this, SLOT(updatePallete()));
     updatePallete();
 
-    setWindowIcon(KIcon("applications-other"));
+    setWindowIcon(KIcon("system-software-install"));
     setButtons(KDialog::User1 | KDialog::Ok | KDialog::Cancel);
     setButtonText(KDialog::Ok, i18n("Continue"));
     setButtonIcon(KDialog::Ok, KIcon("go-next"));
@@ -155,7 +155,7 @@ bool SetupWizard::constructWizardLayout()
 
     QLabel *pix = new QLabel(detailsP);
 
-    LiTrustLevel trust = li_installer_get_package_trust_level(d->setup);
+    LiTrustLevel trust = li_installer_get_package_trust_level(d->setup, NULL);
     if (trust == LI_TRUST_LEVEL_HIGH)
         pix->setPixmap(KIcon("security-high").pixmap (32, 32));
     else if ((trust == LI_TRUST_LEVEL_LOW) || (trust == LI_TRUST_LEVEL_MEDIUM))
@@ -305,7 +305,7 @@ bool SetupWizard::initialize(const QString& ipkFName)
     ui->stackedWidget->addWidget(d->infoPage);
 
     // Load the package file, required to have metadata
-    li_installer_open_file(d->setup, ipkFName.toUtf8(), &error);
+    li_installer_open_file(d->setup, ipkFName.toUtf8().data(), &error);
     if (error != NULL) {
         this->showError(QString::fromUtf8(error->message));
         g_error_free (error);
@@ -314,7 +314,7 @@ bool SetupWizard::initialize(const QString& ipkFName)
 
     data = li_installer_get_appstream_data (d->setup);
     mdata = as_metadata_new ();
-    as_metadata_parse_data (mdata, data, &error);
+    as_metadata_parse (mdata, data, AS_FORMAT_KIND_XML, &error);
     g_free (data);
     if (error != NULL) {
         this->showError(QString::fromUtf8(error->message));
@@ -322,7 +322,9 @@ bool SetupWizard::initialize(const QString& ipkFName)
         g_object_unref (mdata);
         return false;
     }
-    d->cpt = g_object_ref (as_metadata_get_component (mdata));
+
+    d->cpt = as_metadata_get_component (mdata);
+    g_object_ref (d->cpt);
     d->pki = li_installer_get_package_info (d->setup);
     g_object_unref (mdata);
 
