@@ -40,10 +40,10 @@ public:
     bool isFinished() const;
     Transaction *transaction() const;
 
-signals:
+Q_SIGNALS:
     void canceled();
 
-private slots:
+private Q_SLOTS:
     void finished(PackageKit::Transaction::Exit exit = Transaction::ExitSuccess);
     void package(PackageKit::Transaction::Info info, const QString &packageID, const QString &summary);
     void repoDetail(const QString &repoId, const QString &repoDescription);
