@@ -22,8 +22,8 @@
 #include "daemonhelper.h"
 #include "DBusUpdaterInterface.h"
 
-#include <QtDeclarative/QDeclarativeItem>
-#include <QtDeclarative/QDeclarativeContext>
+#include <QQuickItem>
+#include <QQmlContext>
 
 #include <PackageModel.h>
 #include <PkTransaction.h>
@@ -31,15 +31,14 @@
 #include <ApplicationSortFilterModel.h>
 #include <PkStrings.h>
 #include <PkIcons.h>
+#include <KLocalizedString>
 
 #include <Daemon>
-#include <QDeclarativeEngine>
-
-static const KCatalogLoader loader(QLatin1String("apper"));
+#include <QQmlEngine>
 
 void QmlPlugins::registerTypes(const char* uri)
 {
-    Q_ASSERT(uri == QLatin1String("org.kde.apper"));
+//    Q_ASSERT(uri == QString(QLatin1String("org.kde.apper")));
 
     qmlRegisterType<DaemonHelper>(uri, 0, 1, "DaemonHelper");
     qmlRegisterType<DBusUpdaterInterface>(uri, 0, 1, "DBusUpdaterInterface");
@@ -48,7 +47,7 @@ void QmlPlugins::registerTypes(const char* uri)
     qmlRegisterType<PkTransactionProgressModel>(uri, 0, 1, "PkTransactionProgressModel");
     qmlRegisterType<ApplicationSortFilterModel>(uri, 0, 1, "ApplicationSortFilterModel");
     qmlRegisterType<PackageKit::Transaction>(uri, 0, 1, "Transaction");
-    qmlRegisterUncreatableType<PackageKit::Daemon>(uri, 0, 1, "Daemon", "Global");
+    qmlRegisterUncreatableType<PackageKit::Daemon>(uri, 0, 1, "Daemon", QLatin1String("Global"));
     qRegisterMetaType<PkTransaction::ExitStatus>("PkTransaction::ExitStatus");
     qRegisterMetaType<PackageKit::Daemon::Network>("PackageKit::Daemon::Network");
     qRegisterMetaType<PackageKit::Daemon::Authorize>("PackageKit::Daemon::Authorize");
@@ -57,7 +56,7 @@ void QmlPlugins::registerTypes(const char* uri)
     qRegisterMetaType<PackageKit::Transaction::Error>("PackageKit::Transaction::Error");
     qRegisterMetaType<PackageKit::Transaction::Exit>("PackageKit::Transaction::Exit");
     qRegisterMetaType<PackageKit::Transaction::Filter>("PackageKit::Transaction::Filter");
-    qRegisterMetaType<PackageKit::Transaction::Message>("PackageKit::Transaction::Message");
+//    qRegisterMetaType<PackageKit::Transaction::Message>("PackageKit::Transaction::Message");
     qRegisterMetaType<PackageKit::Transaction::Status>("PackageKit::Transaction::Status");
     qRegisterMetaType<PackageKit::Transaction::MediaType>("PackageKit::Transaction::MediaType");
     qRegisterMetaType<PackageKit::Transaction::DistroUpgrade>("PackageKit::Transaction::DistroUpgrade");
@@ -71,15 +70,15 @@ void QmlPlugins::registerTypes(const char* uri)
 
 }
 
-void QmlPlugins::initializeEngine(QDeclarativeEngine *engine, const char *uri)
+void QmlPlugins::initializeEngine(QQmlEngine *engine, const char *uri)
 {
     Q_UNUSED(uri)
-    Q_ASSERT(uri == QLatin1String("org.kde.apper"));
+//    Q_ASSERT(uri == QLatin1String("org.kde.apper"));
 
-    engine->rootContext()->setContextProperty("Daemon", Daemon::global());
-    engine->rootContext()->setContextProperty("PkStrings", new PkStrings);
-    engine->rootContext()->setContextProperty("PkIcons", new PkIcons);
-    engine->rootContext()->setContextProperty("DaemonHelper", new DaemonHelper);
+    KLocalizedString::setApplicationDomain("apper");
+
+    engine->rootContext()->setContextProperty(QLatin1String("Daemon"), Daemon::global());
+    engine->rootContext()->setContextProperty(QLatin1String("PkStrings"), new PkStrings);
+    engine->rootContext()->setContextProperty(QLatin1String("PkIcons"), new PkIcons);
+    engine->rootContext()->setContextProperty(QLatin1String("DaemonHelper"), new DaemonHelper);
 }
-
-Q_EXPORT_PLUGIN2(apper, QmlPlugins)
