@@ -21,19 +21,19 @@
 #ifndef PK_STRINGS_H
 #define PK_STRINGS_H
 
-#include <kdemacros.h>
+//#include <kdemacros.h>
 
 #include <Transaction>
 
-class KDE_EXPORT PkStrings : public QObject
+class Q_DECL_EXPORT PkStrings : public QObject
 {
     Q_OBJECT
-public slots:
+public Q_SLOTS:
     static QString infoPresent(PackageKit::Transaction::Info info);
     static QString infoPast(PackageKit::Transaction::Info info);
     static QString error(PackageKit::Transaction::Error error);
     static QString errorMessage(PackageKit::Transaction::Error error);
-    static QString message(PackageKit::Transaction::Message type);
+//    static QString message(PackageKit::Transaction::Message type);
     static QString status(PackageKit::Transaction::Status status, uint speed = 0, qulonglong downloadRemaining = 0);
     static QString statusPast(PackageKit::Transaction::Status status);
     static QString groups(PackageKit::Transaction::Group group);
