@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008-2011 by Daniel Nicoletti                           *
+ *   Copyright (C) 2008-2018 by Daniel Nicoletti                           *
  *   dantti12@gmail.com                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -22,20 +22,18 @@
 
 #include "PkTransaction.h"
 
-#include <KLocale>
+#include <KLocalizedString>
 #include <KMessageBox>
-#include <KPushButton>
-#include <KService>
+#include <QPushButton>
 #include <KPixmapSequence>
-#include <KPixmapSequenceOverlayPainter>
+#include <KConfig>
+#include <KConfigGroup>
 
-#include <KDebug>
+#include <QLoggingCategory>
 
-#include <QStringBuilder>
-#include <QPropertyAnimation>
 #include <QtDBus/QDBusMessage>
 #include <QtDBus/QDBusConnection>
-#include <QtGui/QTreeView>
+#include <QTreeView>
 
 #include <Daemon>
 
@@ -50,6 +48,8 @@
 #include "PkTransactionProgressModel.h"
 #include "PkTransactionWidget.h"
 
+Q_DECLARE_LOGGING_CATEGORY(APPER_LIB)
+
 class PkTransactionPrivate
 {
 public:
@@ -136,7 +136,7 @@ void PkTransaction::removePackages(const QStringList &packages)
 {
 //    if (Daemon::global()->roles() & Transaction::RoleRemovePackages) {
         d->originalRole = Transaction::RoleRemovePackages;
-        d->allowDeps = false; // Default to avoid dependencies removal unless simulate says so
+        d->allowDeps = true; // *was* false, Default to avoid dependencies removal unless simulate says so, except for https://bugs.kde.org/show_bug.cgi?id=315063
         d->packages = packages;
         d->flags = Transaction::TransactionFlagOnlyTrusted | Transaction::TransactionFlagSimulate;
 
@@ -191,7 +191,7 @@ void PkTransaction::updatePackages()
 
 void PkTransaction::requeueTransaction()
 {
-    Requirements *requires = qobject_cast<Requirements *>(sender());
+    auto requires = qobject_cast<Requirements *>(sender());
     if (requires) {
         // As we have requires allow deps removal
         d->allowDeps = true;
@@ -233,7 +233,7 @@ void PkTransaction::requeueTransaction()
 
 void PkTransaction::slotErrorCode(Transaction::Error error, const QString &details)
 {
-    kDebug() << "errorCode: " << error << details;
+    qCDebug(APPER_LIB) << "errorCode: " << error << details;
     d->error = error;
 
     if (d->handlingActionRequired) {
@@ -253,6 +253,12 @@ void PkTransaction::slotErrorCode(Transaction::Error error, const QString &detai
     case Transaction::ErrorCannotInstallRepoUnsigned:
     case Transaction::ErrorCannotUpdateRepoUnsigned:
     {
+        if (d->role == Transaction::RoleRefreshCache) {
+            // We are not installing anything
+            KMessageBox::information(d->parentWindow, details, PkStrings::error(error));
+            return;
+        }
+
         d->handlingActionRequired = true;
         int ret = KMessageBox::warningYesNo(d->parentWindow,
                                             i18n("You are about to install unsigned packages that can compromise your system, "
@@ -271,7 +277,7 @@ void PkTransaction::slotErrorCode(Transaction::Error error, const QString &detai
     }
     default:
         d->showingError = true;
-        showSorry(PkStrings::error(error), PkStrings::errorMessage(error), QString(details).replace('\n', "<br>"));
+        showSorry(PkStrings::error(error), PkStrings::errorMessage(error), QString(details).replace(QLatin1Char('\n'), QLatin1String("<br>")));
 
         // when we receive an error we are done
         setExitStatus(Failed);
@@ -288,27 +294,18 @@ void PkTransaction::slotEulaRequired(const QString &eulaID, const QString &packa
         d->handlingActionRequired = true;
     }
 
-    LicenseAgreement *eula = new LicenseAgreement(eulaID, packageID, vendor, licenseAgreement, d->parentWindow);
-    connect(eula, SIGNAL(yesClicked()), this, SLOT(acceptEula()));
-    connect(eula, SIGNAL(rejected()), this, SLOT(reject()));
-    showDialog(eula);
-}
-
-void PkTransaction::acceptEula()
-{
-    LicenseAgreement *eula = qobject_cast<LicenseAgreement*>(sender());
-
-    if (eula) {
-        kDebug() << "Accepting EULA" << eula->id();
+    auto eula = new LicenseAgreement(eulaID, packageID, vendor, licenseAgreement, d->parentWindow);
+    connect(eula, &LicenseAgreement::accepted, this, [this, eula] () {
+        qCDebug(APPER_LIB) << "Accepting EULA" << eula->id();
         setupTransaction(Daemon::acceptEula(eula->id()));
-    } else {
-        kWarning() << "something is broken, slot is bound to LicenseAgreement but signalled from elsewhere.";
-    }
+    });
+    connect(eula, &LicenseAgreement::rejected, this, &PkTransaction::reject);
+    showDialog(eula);
 }
 
 void PkTransaction::slotChanged()
 {
-    Transaction *transaction = qobject_cast<Transaction*>(sender());
+    auto transaction = qobject_cast<Transaction*>(sender());
     d->downloadSizeRemaining = transaction->downloadSizeRemaining();
     d->role = transaction->role();
 
@@ -329,7 +326,7 @@ void PkTransaction::slotChanged()
         // Use our own cached tid to avoid crashes
         message << qVariantFromValue(_tid);
         if (!QDBusConnection::sessionBus().send(message)) {
-            kWarning() << "Failed to put WatchTransaction on the DBus queue";
+            qCWarning(APPER_LIB) << "Failed to put WatchTransaction on the DBus queue";
         }
     }
 }
@@ -371,22 +368,13 @@ void PkTransaction::slotRepoSignature(const QString &packageID,
         d->handlingActionRequired = true;
     }
 
-    RepoSig *repoSig = new RepoSig(packageID, repoName, keyUrl, keyUserid, keyId, keyFingerprint, keyTimestamp, type, d->parentWindow);
-    connect(repoSig, SIGNAL(yesClicked()), this, SLOT(installSignature()));
-    connect(repoSig, SIGNAL(rejected()), this, SLOT(reject()));
-    showDialog(repoSig);
-}
-
-void PkTransaction::installSignature()
-{
-    RepoSig *repoSig = qobject_cast<RepoSig*>(sender());
-
-    if (repoSig)  {
-        kDebug() << "Installing Signature" << repoSig->keyID();
+    auto repoSig = new RepoSig(packageID, repoName, keyUrl, keyUserid, keyId, keyFingerprint, keyTimestamp, type, d->parentWindow);
+    connect(repoSig, &RepoSig::accepted, this, [this, repoSig] () {
+        qCDebug(APPER_LIB) << "Installing Signature" << repoSig->keyID();
         setupTransaction(Daemon::installSignature(repoSig->sigType(), repoSig->keyID(), repoSig->packageID()));
-    } else {
-        kWarning() << "something is broken, slot is bound to RepoSig but signalled from elsewhere.";
-    }
+    });
+    connect(repoSig, &RepoSig::rejected, this, &PkTransaction::reject);
+    showDialog(repoSig);
 }
 
 void PkTransaction::slotFinished(Transaction::Exit status)
@@ -397,7 +385,7 @@ void PkTransaction::slotFinished(Transaction::Exit status)
     Requirements *requires = 0;
     Transaction::Role _role = qobject_cast<Transaction*>(sender())->role();
     d->transaction = 0; // Will be deleted later
-    kDebug() << status << _role;
+    qCDebug(APPER_LIB) << status << _role;
 
     switch (_role) {
     case Transaction::RoleInstallSignature:
@@ -422,7 +410,7 @@ void PkTransaction::slotFinished(Transaction::Exit status)
             d->simulateModel->finished();
 
             // Remove the transaction packages
-            foreach (const QString &packageID, d->packages) {
+            for (const QString &packageID : qAsConst(d->packages)) {
                 d->simulateModel->removePackage(packageID);
             }
 
@@ -434,8 +422,8 @@ void PkTransaction::slotFinished(Transaction::Exit status)
 
             requires = new Requirements(d->simulateModel, d->parentWindow);
             requires->setDownloadSizeRemaining(d->downloadSizeRemaining);
-            connect(requires, SIGNAL(accepted()), this, SLOT(requeueTransaction()));
-            connect(requires, SIGNAL(rejected()), this, SLOT(reject()));
+            connect(requires, &Requirements::accepted, this, &PkTransaction::requeueTransaction);
+            connect(requires, &Requirements::rejected, this, &PkTransaction::reject);
             if (requires->shouldShow()) {
                 showDialog(requires);
             } else {
@@ -446,7 +434,7 @@ void PkTransaction::slotFinished(Transaction::Exit status)
                 requeueTransaction();
             }
         } else {
-            KConfig config("apper");
+            KConfig config(QLatin1String("apper"));
             KConfigGroup transactionGroup(&config, "Transaction");
             bool showApp = transactionGroup.readEntry("ShowApplicationLauncher", true);
             if (showApp &&
@@ -462,8 +450,7 @@ void PkTransaction::slotFinished(Transaction::Exit status)
                     delete d->launcher;
                 }
                 d->launcher = new ApplicationLauncher(d->parentWindow);
-                connect(this, SIGNAL(files(QString,QStringList)),
-                        d->launcher, SLOT(files(QString,QStringList)));
+                connect(d->transaction, &Transaction::files, d->launcher, &ApplicationLauncher::files);
 
                 setupTransaction(Daemon::getFiles(d->newPackages));
                 d->newPackages.clear();
@@ -474,7 +461,7 @@ void PkTransaction::slotFinished(Transaction::Exit status)
                 // if we have a launcher and the laucher has applications
                 // show them to the user
                 showDialog(d->launcher);
-                connect(d->launcher, SIGNAL(finished()), SLOT(setExitStatus()));
+                connect(d->launcher, &ApplicationLauncher::finished, this, &PkTransaction::setExitStatus);
                 return;
             }
             setExitStatus(Success);
@@ -484,9 +471,9 @@ void PkTransaction::slotFinished(Transaction::Exit status)
     case Transaction::ExitKeyRequired:
     case Transaction::ExitEulaRequired:
     case Transaction::ExitMediaChangeRequired:
-        kDebug() << "finished KeyRequired or EulaRequired: " << status;
+        qCDebug(APPER_LIB) << "finished KeyRequired or EulaRequired: " << status;
         if (!d->handlingActionRequired) {
-            kDebug() << "Not Handling Required Action";
+            qCDebug(APPER_LIB) << "Not Handling Required Action";
             setExitStatus(Failed);
         }
         break;
@@ -498,12 +485,12 @@ void PkTransaction::slotFinished(Transaction::Exit status)
         break;
     case Transaction::ExitFailed:
         if (!d->handlingActionRequired && !d->showingError) {
-            kDebug() << "Yep, we failed.";
+            qCDebug(APPER_LIB) << "Yep, we failed.";
             setExitStatus(Failed);
         }
         break;
     default :
-        kDebug() << "finished default" << status;
+        qCDebug(APPER_LIB) << "finished default" << status;
         setExitStatus(Failed);
         break;
     }
@@ -516,7 +503,7 @@ PkTransaction::ExitStatus PkTransaction::exitStatus() const
 
 bool PkTransaction::isFinished() const
 {
-    kDebug() << d->transaction->status() << d->transaction->role();
+    qCDebug(APPER_LIB) << d->transaction->status() << d->transaction->role();
     return d->transaction->status() == Transaction::StatusFinished;
 }
 
@@ -615,17 +602,17 @@ void PkTransaction::setTrusted(bool trusted)
     }
 }
 
-void PkTransaction::setExitStatus(PkTransaction::ExitStatus status)
+void PkTransaction::setExitStatus(int status)
 {
-    kDebug() << status;
+    qCDebug(APPER_LIB) << status;
     if (d->launcher) {
         d->launcher->deleteLater();
         d->launcher = 0;
     }
 
-    d->exitStatus = status;
+    d->exitStatus = static_cast<PkTransaction::ExitStatus>(status);
     if (!d->handlingActionRequired || !d->showingError) {
-        emit finished(status);
+        emit finished(d->exitStatus);
     }
 }
 
@@ -643,65 +630,40 @@ void PkTransaction::setupTransaction(Transaction *transaction)
     if (!(transaction->transactionFlags() & Transaction::TransactionFlagSimulate) &&
             transaction->role() != Transaction::RoleGetUpdates &&
             transaction->role() != Transaction::RoleGetUpdateDetail) {
-        connect(transaction, SIGNAL(repoDetail(QString,QString,bool)),
-                d->progressModel, SLOT(currentRepo(QString,QString,bool)));
-        connect(transaction, SIGNAL(package(PackageKit::Transaction::Info,QString,QString)),
-                d->progressModel, SLOT(currentPackage(PackageKit::Transaction::Info,QString,QString)));
-        connect(transaction, SIGNAL(itemProgress(QString,PackageKit::Transaction::Status,uint)),
-                d->progressModel, SLOT(itemProgress(QString,PackageKit::Transaction::Status,uint)));
+        connect(transaction, &Transaction::repoDetail, d->progressModel, &PkTransactionProgressModel::currentRepo);
+        connect(transaction, &Transaction::package, d->progressModel, &PkTransactionProgressModel::currentPackage);
+        connect(transaction, &Transaction::itemProgress, d->progressModel, &PkTransactionProgressModel::itemProgress);
     }
 
-    connect(transaction, SIGNAL(updateDetail(QString,QStringList,QStringList,QStringList,QStringList,QStringList,PackageKit::Transaction::Restart,QString,QString,PackageKit::Transaction::UpdateState,QDateTime,QDateTime)),
-            SIGNAL(updateDetail(QString,QStringList,QStringList,QStringList,QStringList,QStringList,PackageKit::Transaction::Restart,QString,QString,PackageKit::Transaction::UpdateState,QDateTime,QDateTime)));
-    connect(transaction, SIGNAL(package(PackageKit::Transaction::Info,QString,QString)),
-            SIGNAL(package(PackageKit::Transaction::Info,QString,QString)));
-    connect(transaction, SIGNAL(errorCode(PackageKit::Transaction::Error,QString)),
-            SIGNAL(errorCode(PackageKit::Transaction::Error,QString)));
+    connect(transaction, &Transaction::updateDetail, this, &PkTransaction::updateDetail);
+    connect(transaction, &Transaction::package, this, &PkTransaction::package);
+    connect(transaction, &Transaction::errorCode, this, &PkTransaction::errorCode);
 
     // Required actions
-    connect(transaction, SIGNAL(allowCancelChanged()),
-            SIGNAL(allowCancelChanged()));
-    connect(transaction, SIGNAL(downloadSizeRemainingChanged()),
-            SIGNAL(downloadSizeRemainingChanged()));
-    connect(transaction, SIGNAL(elapsedTimeChanged()),
-            SIGNAL(elapsedTimeChanged()));
-    connect(transaction, SIGNAL(isCallerActiveChanged()),
-            SIGNAL(isCallerActiveChanged()));
-    connect(transaction, SIGNAL(lastPackageChanged()),
-            SIGNAL(lastPackageChanged()));
-    connect(transaction, SIGNAL(percentageChanged()),
-            SIGNAL(percentageChanged()));
-    connect(transaction, SIGNAL(remainingTimeChanged()),
-            SIGNAL(remainingTimeChanged()));
-    connect(transaction, SIGNAL(roleChanged()),
-            SIGNAL(roleChanged()));
-    connect(transaction, SIGNAL(speedChanged()),
-            SIGNAL(speedChanged()));
-    connect(transaction, SIGNAL(statusChanged()),
-            SIGNAL(statusChanged()));
-    connect(transaction, SIGNAL(transactionFlagsChanged()),
-            SIGNAL(transactionFlagsChanged()));
-    connect(transaction, SIGNAL(uidChanged()),
-            SIGNAL(uidChanged()));
+    connect(transaction, &Transaction::allowCancelChanged, this, &PkTransaction::allowCancelChanged);
+    connect(transaction, &Transaction::downloadSizeRemainingChanged, this, &PkTransaction::downloadSizeRemainingChanged);
+    connect(transaction, &Transaction::elapsedTimeChanged, this, &PkTransaction::elapsedTimeChanged);
+    connect(transaction, &Transaction::isCallerActiveChanged, this, &PkTransaction::isCallerActiveChanged);
+    connect(transaction, &Transaction::lastPackageChanged, this, &PkTransaction::lastPackageChanged);
+    connect(transaction, &Transaction::percentageChanged, this, &PkTransaction::percentageChanged);
+    connect(transaction, &Transaction::remainingTimeChanged, this, &PkTransaction::remainingTimeChanged);
+    connect(transaction, &Transaction::roleChanged, this, &PkTransaction::roleChanged);
+    connect(transaction, &Transaction::speedChanged, this, &PkTransaction::speedChanged);
+    connect(transaction, &Transaction::statusChanged, this, &PkTransaction::statusChanged);
+    connect(transaction, &Transaction::transactionFlagsChanged, this, &PkTransaction::transactionFlagsChanged);
+    connect(transaction, &Transaction::uidChanged, this, &PkTransaction::uidChanged);
 
-    connect(transaction, SIGNAL(downloadSizeRemainingChanged()),
-            SLOT(slotChanged()));
-    connect(transaction, SIGNAL(errorCode(PackageKit::Transaction::Error,QString)),
-            SLOT(slotErrorCode(PackageKit::Transaction::Error,QString)));
-    connect(transaction, SIGNAL(eulaRequired(QString,QString,QString,QString)),
-            SLOT(slotEulaRequired(QString,QString,QString,QString)));
-    connect(transaction, SIGNAL(mediaChangeRequired(PackageKit::Transaction::MediaType,QString,QString)),
-            SLOT(slotMediaChangeRequired(PackageKit::Transaction::MediaType,QString,QString)));
-    connect(transaction, SIGNAL(repoSignatureRequired(QString,QString,QString,QString,QString,QString,QString,PackageKit::Transaction::SigType)),
-            SLOT(slotRepoSignature(QString,QString,QString,QString,QString,QString,QString,PackageKit::Transaction::SigType)));
+    connect(transaction, &Transaction::downloadSizeRemainingChanged, this, &PkTransaction::slotChanged);
+    connect(transaction, &Transaction::errorCode, this, &PkTransaction::slotErrorCode);
+    connect(transaction, &Transaction::eulaRequired, this, &PkTransaction::slotEulaRequired);
+    connect(transaction, &Transaction::mediaChangeRequired, this, &PkTransaction::slotMediaChangeRequired);
+    connect(transaction, &Transaction::repoSignatureRequired, this, &PkTransaction::slotRepoSignature);
 
-    connect(transaction, SIGNAL(finished(PackageKit::Transaction::Exit,uint)),
-            SLOT(slotFinished(PackageKit::Transaction::Exit)));
+    connect(transaction, &Transaction::finished, this, &PkTransaction::slotFinished);
 
     if (d->flags & Transaction::TransactionFlagSimulate) {
         d->simulateModel = new PackageModel(this);
-        connect(d->transaction, SIGNAL(package(PackageKit::Transaction::Info,QString,QString)),
-                d->simulateModel, SLOT(addPackage(PackageKit::Transaction::Info,QString,QString)));
+        connect(d->transaction, &Transaction::package, d->simulateModel, &PackageModel::addNotSelectedPackage);
     }
 
 #ifdef HAVE_DEBCONFKDE
@@ -724,16 +686,16 @@ void PkTransaction::setupTransaction(Transaction *transaction)
     }
 
     if (!QDBusConnection::sessionBus().send(message)) {
-        kWarning() << "Failed to put SetupDebconfDialog message in DBus queue";
+        qCWarning(APPER_LIB) << "Failed to put SetupDebconfDialog message in DBus queue";
     }
 
     transaction->setHints(QLatin1String("frontend-socket=") % socket);
 #endif //HAVE_DEBCONFKDE
 }
 
-void PkTransaction::showDialog(KDialog *dlg)
+void PkTransaction::showDialog(QDialog *dlg)
 {
-    PkTransactionWidget *widget = qobject_cast<PkTransactionWidget *>(d->parentWindow);
+    auto widget = qobject_cast<PkTransactionWidget *>(d->parentWindow);
     if (!widget || widget->isCancelVisible()) {
         dlg->setModal(d->parentWindow);
         dlg->show();
@@ -745,7 +707,7 @@ void PkTransaction::showDialog(KDialog *dlg)
 
 void PkTransaction::showError(const QString &title, const QString &description, const QString &details)
 {
-    PkTransactionWidget *widget = qobject_cast<PkTransactionWidget *>(d->parentWindow);
+    auto widget = qobject_cast<PkTransactionWidget *>(d->parentWindow);
     if (!widget || widget->isCancelVisible()) {
         if (details.isEmpty()) {
             if (d->parentWindow) {
@@ -763,7 +725,7 @@ void PkTransaction::showError(const QString &title, const QString &description,
 
 void PkTransaction::showSorry(const QString &title, const QString &description, const QString &details)
 {
-    PkTransactionWidget *widget = qobject_cast<PkTransactionWidget *>(d->parentWindow);
+    auto widget = qobject_cast<PkTransactionWidget *>(d->parentWindow);
     if (!widget || widget->isCancelVisible()) {
         if (details.isEmpty()) {
             KMessageBox::sorry(d->parentWindow, description, title);
@@ -800,4 +762,4 @@ void PkTransaction::enableJobWatcher(bool enable)
     d->jobWatcher = enable;
 }
 
-#include "PkTransaction.moc"
+#include "moc_PkTransaction.cpp"
